/* $Id: nglobal.h,v 1.3 2000/05/23 14:48:40 proff Exp $
 * $Copyright$
 */

#ifndef NGLOBAL_H
#define NGLOBAL_H

#include "standard.h"
#include "libproff.h"
#include "nnconf.h"

#include "assert.h"

#include "nmalloc.h"

#include "ll.h"
#include "nlist.h"
#include "log.h"
#include "nntp.h"
#include "nntpcache.h"
#include "sockets.h"
#include "stats.h"

#endif /* NGLOBAL_H */
